@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010,2011,2012,2013,2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -14,10 +14,12 @@
 #define GPGPROC_H
 
 #include <QString>
-#include <QStringList>
 
+#include "kgpgcompiler.h"
 #include "klinebufferedprocess.h"
 
+class QStringList;
+
 /**
  * @brief A interface to GnuPG handling UTF8 recoding correctly
  *
@@ -43,7 +45,7 @@ public:
      * @param parent parent object
      * @param binary path to GnuPG binary or QString() to use the configured
      */
-    explicit GPGProc(QObject *parent = 0, const QString &binary = QString());
+    explicit GPGProc(QObject *parent = Q_NULLPTR, const QString &binary = QString());
 
     /**
      * Destructor
@@ -127,6 +129,7 @@ public:
      * The returned string is the version information without any leading text.
      */
     static QString gpgVersionString(const QString &binary);
+
     /**
      * @brief find users GnuPG directory
      * @param binary name or path to GnuPG binary
@@ -137,6 +140,15 @@ public:
      */
     static QString getGpgHome(const QString &binary);
 
+    /**
+     * @brief return a list of the public key algorithms GnuPG announces support for
+     * @param binary name or path to GnuPG binary
+     * @return list of algorithm names
+     *
+     * All '?' entries are removed.
+     */
+    static QStringList getGpgPubkeyAlgorithms(const QString &binary);
+
     /**
      * @brief run GnuPG and check if it complains about anything
      * @param binary the GnuPG binary to run
