@@ -108,8 +108,8 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
 	m_keywaschanged(false),
 	m_closewhendone(false)
 {
-	Q_ASSERT(m_model != NULL);
-	Q_ASSERT(m_node != NULL);
+	Q_ASSERT(m_model != Q_NULLPTR);
+	Q_ASSERT(m_node != Q_NULLPTR);
 
     setupUi(this);
 
@@ -121,7 +121,7 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
     m_email->setUnderline(false);
     m_trust = new KgpgTrustLabel(this);
     int trustRow;
-    formLayout_keyproperties->getWidgetPosition(tl_trust, &trustRow, NULL);
+    formLayout_keyproperties->getWidgetPosition(tl_trust, &trustRow, Q_NULLPTR);
     formLayout_keyproperties->setWidget(trustRow, QFormLayout::FieldRole, m_trust);
 
     // Hide some widgets if this is not a secret node.
@@ -159,7 +159,7 @@ void KgpgKeyInfo::reloadNode()
 	m_model->refreshKey(m_node);
 
 	m_node = m_model->getRootNode()->findKey(kid);
-	if (m_node != NULL) {
+	if (m_node != Q_NULLPTR) {
 		displayKey();
 	} else {
 		KMessageBox::error(this, i18n("<qt>The requested key is not present in the keyring anymore.<br />Perhaps it was deleted by another application</qt>"), i18n("Key not found"));
@@ -374,7 +374,7 @@ void KgpgKeyInfo::slotKeyExpanded()
 	int i = 2;
 	const KGpgSignableNode *uat;
 
-	while ((uat = m_node->getUid(i++)) != NULL) {
+	while ((uat = m_node->getUid(i++)) != Q_NULLPTR) {
 		if (uat->getType() != KgpgCore::ITYPE_UAT)
 			continue;
 
