@@ -150,10 +150,10 @@ readPublicKeysProcess(GPGProc &p, KGpgKeyNode *readNode)
 	QStringList lsp;
 	int items;
 	KgpgCore::KgpgKeyList publiclistkeys;
-	KgpgCore::KgpgKey *publickey = NULL;
+	KgpgCore::KgpgKey *publickey = Q_NULLPTR;
 	unsigned int idIndex = 0;
 	QString log;
-	KGpgSignableNode *currentSNode = NULL;	///< the current (sub)node signatures are read for
+	KGpgSignableNode *currentSNode = Q_NULLPTR;	///< the current (sub)node signatures are read for
 
 	while ((items = p.readln(lsp)) >= 0) {
 		if ((lsp.at(0) == QLatin1String( "pub" )) && (items >= 10)) {
@@ -193,7 +193,7 @@ readPublicKeysProcess(GPGProc &p, KGpgKeyNode *readNode)
 		} else if (publickey && (lsp.at(0) == QLatin1String("fpr")) && (items >= 10)) {
 			const QString fingervalue = lsp.at(9);
 
-			if ((currentSNode != NULL) && (currentSNode->getType() == ITYPE_SUB))
+			if ((currentSNode != Q_NULLPTR) && (currentSNode->getType() == ITYPE_SUB))
 				static_cast<KGpgSubkeyNode *>(currentSNode)->setFingerprint(fingervalue);
 			else
 				publickey->setFingerprint(fingervalue);
@@ -218,13 +218,13 @@ readPublicKeysProcess(GPGProc &p, KGpgKeyNode *readNode)
 				sub.setExpiration(QDateTime::fromTime_t(lsp.at(6).toUInt()));
 
 			publickey->subList()->append(sub);
-			if (readNode == NULL)
-				currentSNode = NULL;
+			if (readNode == Q_NULLPTR)
+				currentSNode = Q_NULLPTR;
 			else
 				currentSNode = new KGpgSubkeyNode(readNode, sub);
 		} else if (publickey && (lsp.at(0) == QLatin1String( "uat" ))) {
 			idIndex++;
-			if (readNode != NULL) {
+			if (readNode != Q_NULLPTR) {
 				currentSNode = new KGpgUatNode(readNode, idIndex, lsp);
 			}
 		} else if (publickey && (lsp.at(0) == QLatin1String( "uid" )) && (items >= 10)) {
@@ -263,7 +263,7 @@ readPublicKeysProcess(GPGProc &p, KGpgKeyNode *readNode)
 				currentSNode = readNode;
 			} else {
 				idIndex++;
-				if (readNode != NULL) {
+				if (readNode != Q_NULLPTR) {
 					currentSNode = new KGpgUidNode(readNode, idIndex, lsp);
 				}
 			}
@@ -271,7 +271,7 @@ readPublicKeysProcess(GPGProc &p, KGpgKeyNode *readNode)
 			// there are no strings here that could have a recoded QLatin1Char( ':' ) in them
 			const QString signature = lsp.join(QLatin1String(":"));
 
-			if (currentSNode != NULL)
+			if (currentSNode != Q_NULLPTR)
 				(void) new KGpgSignNode(currentSNode, lsp);
 		} else {
 			log += lsp.join(QString(QLatin1Char( ':' ))) + QLatin1Char( '\n' );
@@ -279,7 +279,7 @@ readPublicKeysProcess(GPGProc &p, KGpgKeyNode *readNode)
 	}
 
 	if (p.exitCode() != 0) {
-		KMessageBox::detailedError(NULL, i18n("An error occurred while scanning your keyring"), log);
+		KMessageBox::detailedError(Q_NULLPTR, i18n("An error occurred while scanning your keyring"), log);
 		log.clear();
 	}
 
@@ -300,7 +300,7 @@ KgpgKeyList KgpgInterface::readPublicKeys(const QStringList &ids)
 
 	process.start();
 	process.waitForFinished(-1);
-	return readPublicKeysProcess(process, NULL);
+	return readPublicKeysProcess(process, Q_NULLPTR);
 }
 
 void KgpgInterface::readSignatures(KGpgKeyNode *node)
@@ -328,7 +328,7 @@ readSecretKeysProcess(GPGProc &p)
 	int items;
 	bool hasuid = false;
 	KgpgCore::KgpgKeyList result;
-	KgpgCore::KgpgKey *secretkey = NULL;
+	KgpgCore::KgpgKey *secretkey = Q_NULLPTR;
 
 	while ( (items = p.readln(lsp)) >= 0 ) {
 		if ((lsp.at(0) == QLatin1String( "sec" )) && (items >= 10)) {
