@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2010,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -58,9 +58,7 @@ KGpgGenerateRevoke::nextLine(const QString &line)
 		return false;
 	}
 
-	if (line.contains(QLatin1String( "GOOD_PASSPHRASE" ))) {
-		setSuccess(TS_OK);
-	} else if (line.contains(QLatin1String( "NEED_PASSPHRASE" ))) {
+	if (line.contains(QLatin1String( "NEED_PASSPHRASE" ))) {
 		setSuccess(TS_USER_ABORTED);
 	} else if (line.contains(QLatin1String( "ask_revocation_reason.code" ))) {
 		write(QByteArray::number(m_reason));
@@ -84,8 +82,6 @@ KGpgGenerateRevoke::boolQuestion(const QString& line)
 		return BA_YES;
 	} else if (line == QLatin1String("ask_revocation_reason.okay")) {
 		return BA_YES;
-	} else if (line == QLatin1String("openfile.overwrite.okay")) {
-		return BA_YES;
 	} else {
 		return KGpgTransaction::boolQuestion(line);
 	}
@@ -106,6 +102,21 @@ KGpgGenerateRevoke::finish()
 	}
 }
 
+bool
+KGpgGenerateRevoke::passphraseReceived()
+{
+	setSuccess(TS_OK);
+
+	return false;
+}
+
+KGpgTransaction::ts_boolanswer
+KGpgGenerateRevoke::confirmOverwrite(KUrl &currentFile)
+{
+	currentFile = m_revUrl;
+	return BA_UNKNOWN;
+}
+
 const QString &
 KGpgGenerateRevoke::getOutput() const
 {
